local mod = ...


-- This silent quest reveals sellable resources which are not produced, only sold. Used to avoid an issue with Times and Seasons mod
-- interacting with market carts that "produce" food. When the Seasons modifiers come into effect they also reduce production
-- at market carts, which is incorrect. To get around this, the normal market tables sell the normal food, but the market carts
-- sell an identical but different sellable food. That way the production modifiers do not apply to the food being sold.



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------

mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        "EVENT_MARKET_SELLING",
    }
})



-- Event: Start ---------------------------------------------------------------------------------------------

mod:registerAsset({
	DataType = "EVENT",
    Id = "EVENT_MARKET_SELLING",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysBetweenOccurences = nil,
    DaysToFirst = 1,
    Delay = 10, 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "MONUMENT_MARKET"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_MARKET_SELLING"
        },
    }
})



-- Quest: Build and staff ---------------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "QUEST",
    Id = "QUEST_MARKET_SELLING",
    Name = "QUEST_MARKET_SELLING_NAME",
    Description = "QUEST_MARKET_SELLING_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_BUILD", 
        BuildingListToBuild = {
            "MONUMENT_MARKET"
        }
    },
    QuestRewardActionList = {
        {
            DataType = "QUEST_REWARD_RESOURCES",
            ResourceCollection = {
                {
                    Resource = "RESOURCE_WOOD_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_MILK_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_BERRIES_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_HONEY_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_FRUIT_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_VEGETABLE_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_POULTRY_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_EGG_SELL",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_PAGANISM",
                    Quantity = 0
                },
                {
                    Resource = "RESOURCE_MUSHROOM",
                    Quantity = 0
                },
            }
        },
    },
    QuestFailActionList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

